======================
Nexus Mechanism Driver
======================
The following list of variables are used by the cisco_nexus mechanism driver.
A variable's default value can be changed by adding it to the configuration
file included on the neutron-server command line. The sample nexus configuration
file is described here,
:doc:`samples/ml2-nexus`.

.. show-options::

   networking_cisco.nexus
